package Food.app.ui;

import java.util.ArrayList;
import java.util.regex.Pattern;
import android.util.Log;


/**
 * Help high level class to get the information from FoodRequester
 * Assume FoodRequester get the information from the server;
 * Return higher level class for the phone app.
 * @author Kelly
 *
 */

public class FoodHelper {
	
	private FoodRequester myFR = new FoodRequester();
	
	/**
	 * Retrieve the information for the searched restaurant
	 * @param myRes
	 * @return
	 */
	public Restaurant getRes(Restaurant myRes){
		
		String ResName = myRes.getResName();
		double ResLat = myRes.getResLoc().getLat();
		double ResLong = myRes.getResLoc().getLong();
		return getRes(ResName, ResLat, ResLong);
	
	}
	
	/**
	 * Retrieve the information for the searched restaurant
	 * @param ResName
	 * @param ResLat
	 * @param ResLong
	 * @return
	 */
	public Restaurant getRes(String ResName, double ResLat, double ResLong){
		
		Location myRestaurantLoc = new Location(ResLat, ResLong);
		Restaurant myRestaurant = new Restaurant(ResName, myRestaurantLoc);
		String response = myFR.getRes(ResName, ResLat, ResLong);
		if(response.contains("OK")){
			
			myRestaurantLoc.setAddress(getValue("ResAddr",response));
			myRestaurantLoc.setZipCode(Integer.parseInt(getValue("ResZip",response)));
			myRestaurant.setResPhoneNum(getValue("ResPhone",response));			
		}		
		return myRestaurant;		
	}
	
	/**
	 * Get a specific food 
	 * @param FoodName
	 * @param myRestaurant
	 * @return
	 */
	public Food getFood(String FoodName, Restaurant myRestaurant){
		
		String ResName = myRestaurant.getResName();
		double ResLat = myRestaurant.getResLoc().getLat();
		double ResLong = myRestaurant.getResLoc().getLong();		
		return getFood(FoodName, ResName, ResLat, ResLong);
	}
	/**
	 * Get a specific food 
	 * @param FoodName
	 * @param ResName
	 * @param ResLat
	 * @param ResLong
	 * @return
	 */
	public Food getFood(String FoodName, String ResName, double ResLat, double ResLong){
		
		Location myRestaurantLoc = new Location(ResLat, ResLong);
		Restaurant myRestaurant = new Restaurant(ResName, myRestaurantLoc);
		Food myFood = new Food(FoodName, myRestaurant);
		String response = myFR.getFood(FoodName, ResName, ResLat, ResLong);
		if(response.contains("OK")){
			
			myFood.setFoodPrice(Double.parseDouble(getValue("FoodPrice",response)));
			double totalRate = Double.parseDouble(getValue("FoodRate",response));
			int RateNum = Integer.parseInt(getValue("FoodRateNum",response));			
			myFood.setFoodRate(totalRate/RateNum);				
			ArrayList <Comment> myCommentlist = GetFoodComment(response);			
			if(myCommentlist!=null){
				myFood.setComments(myCommentlist);

			}

		}		
		return myFood;			
	}
	/**
	 * Get a list of comments for one food
	 * @param FoodName
	 * @param ResName
	 * @param ResLat
	 * @param ResLong
	 * @return
	 */
	public ArrayList<Comment> getFoodComment(String FoodName, String ResName, double ResLat, double ResLong){
				
		Food myfood = getFood(FoodName, ResName, ResLat, ResLong);
		if(myfood!=null){
			return myfood.getCommentlist();
		}
		else{
			return null;
		}		
	}
	/**
	 * get a list of comments for one food
	 * @param FoodName
	 * @param myRes
	 * @return
	 */
	public ArrayList<Comment> getFoodComment(String FoodName, Restaurant myRes){
		
		String ResName = myRes.getResName();
		double ResLat = myRes.getResLoc().getLat();
		double ResLong = myRes.getResLoc().getLong();
		
		return getFoodComment(FoodName, ResName, ResLat, ResLong);
				
	}
	/**
	 * get a list of food for one restaurant
	 * @param myRes
	 * @param str
	 * @param end
	 * @return
	 */
	public ArrayList<Food> getResMenu(Restaurant myRes, int str, int end){
		
		String ResName = myRes.getResName();
		double ResLat = myRes.getResLoc().getLat();
		double ResLong = myRes.getResLoc().getLong();
		return getResMenu(ResName, ResLat, ResLong, str, end);
		
	}
	/**
	 * get a list of food for one restaurant
	 * @param ResName
	 * @param ResLat
	 * @param ResLong
	 * @param str
	 * @param end
	 * @return
	 */

	public ArrayList<Food> getResMenu(String ResName, double ResLat, double ResLong, int str, int end){
		
		Location myRestaurantLoc = new Location(ResLat, ResLong);
		Restaurant myRestaurant = new Restaurant(ResName, myRestaurantLoc);	
		String response = myFR.getResMenu(ResName, ResLat, ResLong, str, end);
		if(response.contains("OK")){
			
			String[] mlist = getlist("<FoodEND>" ,response);
		    int numOfFood = mlist.length - 1;	
		    if(numOfFood >0){
		    	
		    	ArrayList<Food> Menu = new ArrayList<Food>();
		    	for(int i = 0; i < numOfFood; i++){

		    		Food myFood = new Food(myRestaurant);
		    		
		    		String FoodName = getValue("FoodName",mlist[i]);
		    		double FoodPrice = Double.parseDouble(getValue("FoodPrice",mlist[i]));
		    		double FoodRate = Double.parseDouble(getValue("FoodRate",mlist[i]));
		    		
		    		myFood.setFoodName(FoodName);
		    		myFood.setFoodPrice(FoodPrice);
		    		myFood.setFoodRate(FoodRate);	
		    		Menu.add(myFood);
		    			
		    	}
		    	return Menu;
		    }
		    else{
		    	return null;
		    }			
		}
		else{
	    	return null;
	    }								
	}
	/**
	 * search food from a range area
	 * @param LatMax
	 * @param LatMin
	 * @param LongMax
	 * @param LongMin
	 * @param FoodName
	 * @param str
	 * @param end
	 * @return
	 */
	public ArrayList<Food> searchFood(double LatMax, double LatMin, double LongMax, double LongMin,String FoodName, int str, int end){
		
		String response = myFR.searchFood(LatMax, LatMin, LongMax, LongMin, FoodName, str, end);
		if(response.contains("OK")){
			
			String[] mlist = getlist("<searchFoodEND>" ,response);
			int numOfFood = mlist.length - 1;	
		    if(numOfFood >0){
		    	ArrayList<Food> Foodlist = new ArrayList<Food>();
		    	for(int i = 0; i < numOfFood; i++){
		    		String ResName = getValue("ResName",mlist[i]);
		    		double ResLat = Double.parseDouble(getValue("ResLat",mlist[i]));
		    		double ResLong = Double.parseDouble(getValue("ResLong",mlist[i]));
		    		Restaurant myRestaurant = new Restaurant(ResName,ResLat,ResLong);
		    		Food myFood = new Food(myRestaurant);
		    		String RealFoodName = getValue("FoodName",mlist[i]);
		    		double FoodPrice = Double.parseDouble(getValue("FoodPrice",mlist[i]));
		    		double FoodRate = Double.parseDouble(getValue("FoodRate",mlist[i]));
		    		myFood.setFoodName(RealFoodName);
		    		myFood.setFoodPrice(FoodPrice);
		    		myFood.setFoodRate(FoodRate);
		    		Foodlist.add(myFood);
		    	}
		    	return Foodlist;
		    	
		    }else{
		    	return null;
		    }
		
		}else{
			return null;
		}
		
	}
	/**
	 * get a list of restaurant in a range
	 * @param myLoc
	 * @param range
	 * @param str
	 * @param end
	 * @return
	 */
	public ArrayList<Restaurant> listLocalRes(Location myLoc, double range, int str, int end){
		
		double Lat = myLoc.getLat();
		double LatMax = Lat + range;
		double LatMin = Lat - range;
		double Long = myLoc.getLong();
		double LongMax = Long + range;
		double LongMin = Long - range;
		return getResList(LatMax, LatMin, LongMax, LongMin, str, end);		
	}
	/**
	 * get a list of picture file names
	 * @param FoodName
	 * @param ResName
	 * @param ResLat
	 * @param ResLong
	 * @param str
	 * @param end
	 * @return
	 */
	public ArrayList<String> DownloadFoodPic(String FoodName, String ResName, double ResLat, double ResLong, int str, int end){
		
		String response = myFR.DownloadFoodPic(FoodName, ResName, ResLat, ResLong, str, end);
		
		Log.i(tag, "response = " + response);
		ArrayList<String> FoodPicNameList = new ArrayList<String>();
		if(response!=null && response.contains("OK")){
			
			String[] mlist = getlist("<DownloadFoodPicEND>" ,response);
			
			int numOfPic = mlist.length;	
			
		    if(numOfPic >0){
		    	
		    	for(int i = 0; i < numOfPic; i++){
		    		String PicPath = getValue("PicPath",mlist[i]).replaceAll(":", "").replaceAll("-", "").replaceAll(" ", "");		    		
		    		FoodPicNameList.add(PicPath);
		    	}
		    }
		}
		
		return FoodPicNameList;
	}

	/**
	 * get a list of picture file names
	 * @param FoodName
	 * @param myRes
	 * @return
	 */
	public ArrayList<String> DownloadFoodPic(String FoodName, Restaurant myRes){

		String ResName = myRes.getResName();
		double ResLat = myRes.getResLoc().getLat();
		double ResLong = myRes.getResLoc().getLong();
		return DownloadFoodPic(FoodName, ResName, ResLat, ResLong);
		
	}
	/**
	 * get a list of picture file names
	 * @param FoodName
	 * @param ResName
	 * @param ResLat
	 * @param ResLong
	 * @return
	 */
	public ArrayList<String> DownloadFoodPic(String FoodName, String ResName, double ResLat, double ResLong){
		
		String response = myFR.DownloadFoodPic(FoodName, ResName, ResLat, ResLong);
		
		Log.i(tag, "response = " + response);
		ArrayList<String> FoodPicNameList = new ArrayList<String>();
		if(response!=null && response.contains("OK")){
			
			String[] mlist = getlist("<DownloadFoodPicEND>" ,response);
			
			int numOfPic = mlist.length;	
			
		    if(numOfPic >0){
		    	
		    	for(int i = 0; i < numOfPic; i++){
		    		String PicPath = getValue("PicPath",mlist[i]).replaceAll(":", "").replaceAll("-", "").replaceAll(" ", "");		    		
		    		FoodPicNameList.add(PicPath);
		    	}
		    }
		}
		
		return FoodPicNameList;
	}
	/**
	 * get a list of picture file names
	 * @param FoodName
	 * @param myRes
	 * @param str
	 * @param end
	 * @return
	 */
	public ArrayList<String> DownloadFoodPic(String FoodName, Restaurant myRes, int str, int end){
		
		String ResName = myRes.getResName();
		double ResLat = myRes.getResLoc().getLat();
		double ResLong = myRes.getResLoc().getLong();
		return DownloadFoodPic(FoodName, ResName, ResLat, ResLong, str, end);
	}

	/**
	 * search a list of food from a given zip
	 * @param FoodName
	 * @param ResZip
	 * @param str
	 * @param end
	 * @return
	 */
	public ArrayList<Food> searchFoodbyZipCode(String FoodName, int ResZip, int str, int end){
		
		String response = myFR.searchFoodbyZipCode(FoodName, ResZip, str, end);
		if(response.contains("OK")){
			
			String[] mlist = getlist("<searchFoodbyZipCodeEND>" ,response);
			int numOfFood = mlist.length - 1;	
		    if(numOfFood >0){
		    	ArrayList<Food> Foodlist = new ArrayList<Food>();
		    	for(int i = 0; i < numOfFood; i++){
		    		String ResName = getValue("ResName",mlist[i]);
		    		double ResLat = Double.parseDouble(getValue("ResLat",mlist[i]));
		    		double ResLong = Double.parseDouble(getValue("ResLong",mlist[i]));
		    		Restaurant myRestaurant = new Restaurant(ResName,ResLat,ResLong);
		    		Food myFood = new Food(myRestaurant);
		    		String RealFoodName = getValue("FoodName",mlist[i]);
		    		double FoodPrice = Double.parseDouble(getValue("FoodPrice",mlist[i]));
		    		double FoodRate = Double.parseDouble(getValue("FoodRate",mlist[i]));
		    		myFood.setFoodName(RealFoodName);
		    		myFood.setFoodPrice(FoodPrice);
		    		myFood.setFoodRate(FoodRate);
		    		Foodlist.add(myFood);
		    	}
		    	return Foodlist;
		    	
		    }else{
		    	return null;
		    }
		
		}else{
			return null;
		}
		
	}
	/**
	 * Rate a food item
	 * @param FoodName
	 * @param FoodRate
	 * @param ResName
	 * @param ResLong
	 * @param ResLat
	 */
	public void RateFood(String FoodName, double FoodRate, String ResName, double ResLong, double ResLat){
		
		myFR.RateFood(FoodName, FoodRate, ResName, ResLat, ResLong);
		
	}
	/**
	 * Rate a food item
	 * @param FoodName
	 * @param FoodRate
	 * @param myRes
	 */
	public void RateFood(String FoodName, double FoodRate, Restaurant myRes){
		
		String ResName = myRes.getResName();
		double ResLat = myRes.getResLoc().getLat();
		double ResLong = myRes.getResLoc().getLong();		
		myFR.RateFood(FoodName, FoodRate, ResName, ResLat, ResLong);		
	}
	/**
	 * Rate a food item
	 * @param FoodName
	 * @param FoodRate
	 * @param ResName
	 * @param myLoc
	 */
	public void RateFood(String FoodName, double FoodRate, String ResName, Location myLoc){
		
		double ResLat = myLoc.getLat();
		double ResLong = myLoc.getLong();		
		myFR.RateFood(FoodName, FoodRate, ResName, ResLat, ResLong);		
	}
	/**
	 * Upload one food picture
	 * @param PicPath
	 * @param FoodName
	 * @param ResName
	 * @param ResLong
	 * @param ResLat
	 */
	public void UploadFoodPic(String PicPath, String FoodName, String ResName, double ResLong, double ResLat){
		
		myFR.UploadFoodPic(PicPath, FoodName, ResName, ResLat, ResLong);
	}
	/**
	 * Upload one food picture
	 * @param PicPath
	 * @param FoodName
	 * @param myRes
	 */
	public void UploadFoodPic(String PicPath, String FoodName, Restaurant myRes){
		
		String ResName = myRes.getResName();
		double ResLat = myRes.getResLoc().getLat();
		double ResLong = myRes.getResLoc().getLong();			
		myFR.UploadFoodPic(PicPath, FoodName, ResName, ResLat, ResLong);
	}
	/**
	 * Upload one food picture
	 * @param PicPath
	 * @param FoodName
	 * @param ResName
	 * @param myLoc
	 */
	public void UploadFoodPic(String PicPath, String FoodName, String ResName, Location myLoc){
		
		double ResLat = myLoc.getLat();
		double ResLong = myLoc.getLong();			
		myFR.UploadFoodPic(PicPath, FoodName, ResName, ResLat, ResLong);
	}	
	/**
	 * Write review for one food item
	 * @param FoodName
	 * @param ResName
	 * @param ResLat
	 * @param ResLong
	 * @param FoodComm
	 */
	public void CommentFood(String FoodName, String ResName, double ResLat, double ResLong, String FoodComm){
		
		myFR.CommentFood(FoodName, ResName, ResLat, ResLong, FoodComm);
	}
	
	/**
	 * Write review for one food item
	 * @param FoodName
	 * @param myRes
	 * @param FoodComm
	 */
	public void CommentFood(String FoodName, Restaurant myRes, String FoodComm){
		
		String ResName = myRes.getResName();
		double ResLat = myRes.getResLoc().getLat();
		double ResLong = myRes.getResLoc().getLong();			
		myFR.CommentFood(FoodName, ResName, ResLat, ResLong, FoodComm);
	}
	/**
	 * Write review for one food item
	 * @param FoodName
	 * @param ResName
	 * @param myLoc
	 * @param FoodComm
	 */
	public void CommentFood(String FoodName, String ResName, Location myLoc, String FoodComm){
		
		double ResLat = myLoc.getLat();
		double ResLong = myLoc.getLong();		
		myFR.CommentFood(FoodName, ResName, ResLat, ResLong, FoodComm);
	}
	
	/**
	 * Get a list of food comments
	 * @param response
	 * @return
	 */
	private ArrayList<Comment> GetFoodComment(String response){
		
		String[] mlist = getlist("<CommNumEND>" ,response);
	    int numOfComment = mlist.length - 1;	    
	    
	    if(numOfComment >0){
	    	
	    	ArrayList <Comment> myCommentList = new ArrayList <Comment>();

	    	for(int i = 0; i < numOfComment; i++){
	    	
	    		int CommNum = Integer.parseInt(getValue("CommNum",mlist[i]));
	    		String CommTime = getValue("CommTime",mlist[i]);
	    		String FoodComm = getValue("FoodComm",mlist[i]);	    			    		
	    		Comment myComment = new Comment(CommNum, FoodComm, CommTime);	    	   
	    		myCommentList.add(myComment);
	    	}
	    	 return myCommentList;
	    }
	    else{
	    	return null;
	    }	   
	}
	/**
	 * get a list of restaurant 
	 * @param LatMax
	 * @param LatMin
	 * @param LongMax
	 * @param LongMin
	 * @param str
	 * @param end
	 * @return
	 */
	public ArrayList<Restaurant> getResList(double LatMax, double LatMin, double LongMax, double LongMin, int str, int end){
		
		String response = myFR.getResList(LatMax, LatMin, LongMax, LongMin, str, end);
		
		String[] mlist = getlist("<ResListEND>" ,response);
		int numOfRes = mlist.length - 1;	    	    
	    if(numOfRes >0){
	    	
	    	ArrayList <Restaurant> myResList = new ArrayList <Restaurant>();

	    	for(int i = 0; i < numOfRes; i++){
	    	
	    		String ResName = getValue("ResName",mlist[i]);
	    		double ResLat = Double.parseDouble(getValue("ResLat",mlist[i]));
	    		double ResLong = Double.parseDouble(getValue("ResLong",mlist[i]));
	    		Restaurant myRestaurant = new Restaurant(ResName, ResLat, ResLong);  	   
	    		myResList.add(myRestaurant);
	    	}
	    	return myResList;
	    }
	    else{
	    	return null;
	    }	   
		
	}	

	/**
	 * Paste items the server send back
	 * @param foodInfo
	 * @return
	 */
	private String [] getlist(String Regex, String foodInfo){
		
		String REGEX = Regex;
	    Pattern mpattern = Pattern.compile(REGEX);
	    String[] mlist = mpattern.split(foodInfo);
	    return mlist;
	}
	

	/**
	 * Get each value from the input string
	 * @param itemName
	 * @param input
	 * @return
	 */

	private String getValue(String itemName, String input){
		
 	   	Pattern patternEnd = Pattern.compile("</"+ itemName + ">");
 	   	patternEnd.matcher(input);		       
 	   	String[] mystring = patternEnd.split(input);
 	   	Pattern FoodpatternStart = Pattern.compile("<"+ itemName + ">");
 	   	FoodpatternStart.matcher(mystring[0]);
 	   	String[] stringlist = FoodpatternStart.split(mystring[0]);
		return stringlist[1];
		
	}
		
	public static String tag = FoodHelper.class.getName();
}
