package Food.app.ui;

import java.util.ArrayList;
import android.app.ListActivity;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.MenuItem;
import android.view.View;
import android.widget.ListView;

/**
 * Activity to display a list of search food result
 * @author kelly
 *
 */
public class FoodListView extends ListActivity implements Constant {
 

	Restaurant MyRes;													// Search Result
	String FoodName;
	String SearchFood;									    			// Search Food Keyword
	int ResZip;
	ArrayList<String> PicPathlst;										// Search Food Path List
	int startIndex = 0;													// Search Start Index
	ArrayList<Food> foodlist = new ArrayList<Food>();					// Search Food List
	FoodHelper FH = new FoodHelper();									// To Communicate with the server
	
	
	@Override
	public void onCreate(Bundle icicle) {
		
		super.onCreate(icicle);
		setContentView(R.layout.foodlistview);
		
		// User Input Key words		
		Intent intent = this.getIntent();
		SearchFood = (String)intent.getStringExtra("SearchFood");
		ResZip = (int) intent.getIntExtra("ResZip", 95127);                //Default Zip Code 95127
		
		Log.i(tag,"ResZip = " + ResZip);
		Log.i(tag,"SearchFood = " + SearchFood);

		
		// Get the search result (a list of food item)
		ArrayList<Food> templist =  FH.searchFoodbyZipCode(SearchFood, ResZip, this.startIndex, FoodListView.END_INDEX_INCREMENT);
		
		if(templist!=null){
			
			foodlist.addAll(templist);	
    		
    		String[] FoodArray = new String[foodlist.size()];						//Food Text Information
    		String[] smallFoodIcon = new String[foodlist.size()]; 					// Food Small Icon
    		
    		int i = 0;
    		for(Food FoodItem: foodlist){
    			
    			// Food General Information
    			FoodArray[i] = FoodItem.getFoodName() + "\n" + "Price: $" + FoodItem.getFoodPrice();
   			
    			// Find the corresponding Restaurant 
    			MyRes = FoodItem.getRestaurant();
    			
    			// Found the Restaurant
    			if(MyRes != null){   				      			 
    				
    				// Get one picture and for Food Small Icon
    				ArrayList<String> tempIcon = FH.DownloadFoodPic(FoodItem.getFoodName(), MyRes, 0, 1);
    				
    				// This Food has pictures, display it as small Icon 
    				if(tempIcon!=null && tempIcon.size()>0){
    					
    				smallFoodIcon[i] = tempIcon.get(0);
    				Log.i(tag, "smallFoodIcon[" + i + "] = " + smallFoodIcon[i]);
    				
    			}
    			// No picture for this food, display a default picture
    			else{
    					
    					smallFoodIcon[i] = DEFAULTPIC;
    					Log.i(tag, "there is no resturant around offer this food!");
    				}
    				
    			}
    			// Restaurant Not Found
    			else{
    				
    				smallFoodIcon[i] = DEFAULTPIC;
    				Log.i(tag, "resturant information is needed!");
    			}   			
    			i++;
    		}    	   		
     		setListAdapter(new IconAdapter(this,FoodArray, smallFoodIcon));   
    	}
		else{
			Log.i(tag, "templist == null");
		}
	}
	/**
	 * handle when user clicks on one item
	 */
	public void onListItemClick(ListView parent, View v, int position, long id) {	

		FoodName = foodlist.get(position).getFoodName();
		MyRes = foodlist.get(position).getRestaurant();
		
		PicPathlst = FH.DownloadFoodPic(FoodName, MyRes);
		
		// No picture for this food item
		if(PicPathlst==null || PicPathlst.size()==0){
			
			PicPathlst.add(DEFAULTPIC);
		}				

		Intent intent = new Intent(this, FoodView.class);  
		this.StoreVariables(intent);
		startActivity(intent);
		
	}
	/**
	 * handle when Menu button, get more food pictures
	 */
	  public boolean onCreateOptionsMenu(android.view.Menu menu){
	    	
	    	MenuItem item = menu.add(0,0,0,"View More Food?");
	    	item.setOnMenuItemClickListener(new MenuItem.OnMenuItemClickListener() {
							
			public boolean onMenuItemClick(MenuItem item) {
					
				startIndex += SEARCH_INCREMENT;
				
				ArrayList<Food> tempFood =  FH.searchFoodbyZipCode(SearchFood, ResZip, startIndex, FoodListView.END_INDEX_INCREMENT);
					
				if(tempFood != null && tempFood.size()>0){
						
					foodlist.addAll(tempFood);
					Log.i(tag, "Size of ArrayList = " + FoodListView.this.foodlist.size());
						
					String[] FoodArray = new String[foodlist.size()];
					String[] smallFoodIcon = new String[foodlist.size()];
						
					int i = 0;
					for(Food FoodItem: foodlist){
							
						// Food General Information
						FoodArray[i] = FoodItem.getFoodName() + "\n$" + "Price: " + FoodItem.getFoodPrice();
							
						// Find the corresponding Restaurant 
						MyRes = FoodItem.getRestaurant();
							
						// Found the Restaurant
						if(MyRes != null){
								
							// Get one picture and for Food Small Icon
							ArrayList<String> tempIcon = FH.DownloadFoodPic(FoodItem.getFoodName(), MyRes, 0, 1);
								
							// This Food has pictures, display it as small Icon 
			    			if(tempIcon!=null && tempIcon.size()>0){
			    					
			    				smallFoodIcon[i] = tempIcon.get(0);
			    				Log.i(tag, "smallFoodIcon[" + i + "] = " + smallFoodIcon[i]);
			    			}
			    			// No picture for this food, display a default picture
			    			else{			    					
		    					smallFoodIcon[i] = DEFAULTPIC;
			    				Log.i(tag, "there is no resturant around offer this food!");
			    			}
						}
						else{
								
							Log.i(tag, "resturant information is needed!");
						}   			
						i++;
					}    	   		
				 	setListAdapter(new IconAdapter(FoodListView.this,FoodArray, smallFoodIcon));
						
				 	FoodListView.super.setSelection(startIndex);
				}
									
				return true;
			}
		});
	    return true;
	}
	  	
	  /**
	   * Store variables for later use
	   * @param intent
	   */
	  private void StoreVariables(Intent intent){
			
			intent.putExtra("MyRes", this.MyRes).putExtra("FoodName", this.FoodName).putExtra("PicPathlst", PicPathlst);
			
		}
	
	// Constants
	final String tag = FoodListView.class.getName();
	final static String DEFAULTPIC = "DefaultPic.jpg";	
	final static int END_INDEX_INCREMENT = 5;
	final static int SEARCH_INCREMENT = END_INDEX_INCREMENT;
}