package Food.app.ui;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;

import android.app.ListActivity;
import android.content.Context;
import android.content.Intent;
import android.location.Address;
import android.location.Geocoder;
import android.location.LocationListener;
import android.location.LocationManager;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.Toast;

/**
 * Display a Restaurant List View 
 * 
 * @author Shengyu (Kelly) Li
 *
 */

public class ResListActivity extends ListActivity implements OnClickListener,Constant {
 
	ArrayList <Restaurant> ResList = new ArrayList <Restaurant>();	
	FoodHelper FH = new FoodHelper();	
	Location myLoc;	
	View Searchbutton;
	View Next5RestaurantButton;
	EditText zipcode;
	EditText Food;	
	int startIndex = 0;
		
	Restaurant MyRes;
	String SearchFood;
	int ResZip;
	
	LocationManager  mlocManager;
	LocationListener mlocListener;
		
	@Override
	public void onCreate(Bundle icicle) {
		
		super.onCreate(icicle);
		setContentView(R.layout.main);
		
		zipcode = (EditText)this.findViewById(R.id.zipcodefield);
				
		this.mlocManager = (LocationManager)getSystemService(Context.LOCATION_SERVICE);
		this.mlocListener = new GPSLocationListener();
		
		if(!DEBUG){
			
			mlocManager.requestLocationUpdates( LocationManager.GPS_PROVIDER, 0, 0, mlocListener);
		}
		else{
			
			android.location.Location defaultLocation = new android.location.Location("");
			defaultLocation.setLatitude(37.331891);
			defaultLocation.setLongitude(-121.87759);
			this.mlocListener.onLocationChanged(defaultLocation);
		}

		Searchbutton = this.findViewById(R.id.searchbutton);
		Searchbutton.setOnClickListener(this);        
        
        Food = (EditText)this.findViewById(R.id.foodnamefield);
        this.Next5RestaurantButton = this.findViewById(R.id.next5RestaurantButton);
        this.Next5RestaurantButton.setOnClickListener(this);
	}
	
	public void onListItemClick(ListView parent, View v, int position, long id) {	
		
		MyRes = ResList.get(position);
		Intent intent = new Intent(this, ResView.class); 		
		StoreVariables(intent);
		startActivity(intent);

	}
	
	public void onClick(View v)
    {
		
		switch(v.getId())
		{
		case R.id.searchbutton:
			
			ResZip = Integer.parseInt(zipcode.getText().toString().trim());
			SearchFood = Food.getText().toString().trim();		
	  		Intent intent;
	  		
			intent = new Intent(this, FoodListView.class);  
			StoreVariables(intent);
			startActivity(intent);
			break;
			
		case R.id.next5RestaurantButton:	//change to new next buttonnoo
			
			this.startIndex += ResListActivity.SEARCH_INCREMENT;
			
			if(myLoc!=null){
				
				ArrayList <Restaurant> tempList = FH.listLocalRes(myLoc, 3, this.startIndex, ResListActivity.END_INDEX_INCREMENT);
			
				if(tempList != null && tempList.size() > 0){
				
					ResList.addAll(tempList);
					Log.i(tag, "Size of ArrayList = " + this.ResList.size());
				
					String [] resNameString = new String[this.ResList.size()];
					String [] picNameString = new String[this.ResList.size()];
	    		
					for(int i = 0; i < this.ResList.size(); i++)
					{
						resNameString[i] = this.ResList.get(i).getResName();
						picNameString[i] = this.ResList.get(i).getResPicName();
					}
	    		
					Log.i(tag, "Length of resNameString = " + resNameString.length);
					Log.i(tag, "Length of picNameString = " + picNameString.length);
					super.setListAdapter(new IconAdapter(this, resNameString, picNameString));	    		
					super.setSelection(this.startIndex);
			}

			}					
			break;
			
		default:
			break;
		}
 		
    }
	/**
	 * 
	 * Get a Location by receiving the GPS signal
	 *
	 */
	
	public class GPSLocationListener implements LocationListener 
	{	
		public void onLocationChanged(android.location.Location loc)
		{
			String Text = "My current location is: " + "Latitude = " + loc.getLatitude() + "Longitud = " + loc.getLongitude();

			Toast.makeText(getApplicationContext(), Text, Toast.LENGTH_LONG).show();
			
			double latitude = loc.getLatitude();
			double longitude = loc.getLongitude();

		
			Log.i(tag, "Latitude = " + latitude);
			Log.i(tag, "Longitude = " + longitude);
			Log.i(tag, "Setting new location from GPS");
			myLoc = new Location(latitude, longitude);
			
			/*
			 * Constructs a Geocoder whose responses will be localized for the given Locale.
			 */
			Geocoder geocoder = new Geocoder(getBaseContext(), Locale.US);
			
			try {
				List<Address> addresses = geocoder.getFromLocation(latitude, longitude, 1);
				

				
         	    if (addresses.size() > 0) {
         	    	  
         	        Address address1 = addresses.get(0);     	        
         	        String CurrentZip = address1.getPostalCode();
         	    
         	        Log.i(tag, "current zip code = " + CurrentZip);
         	       
         	        zipcode.setText(CurrentZip);
        	      
         	   }
         	   else {
         	    
         		   String latLongString = "No location found";
         		   Log.i(tag, latLongString + "addresses1.size() = " + addresses.size() );
         	 
         	  }

			} catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
				
			if(myLoc !=  null)
			{
				Log.i(tag, "myLoc.Latitude = " + myLoc.getLat());
				Log.i(tag, "myLoc.Longitude = " + myLoc.getLong());
			}
			else
			{
				Log.i(tag, "myLoc is null");			
			}
		
			ArrayList <Restaurant> tempList = FH.listLocalRes(myLoc, 3, startIndex, END_INDEX_INCREMENT);
			
			if(tempList != null && tempList.size() != 0){
				
				ResList.addAll(tempList);
				
				if(ResList != null)	//never null
				{    		
					Log.i(tag, "Size of ArrayList = " + ResList.size());
					String [] resNameString = new String[ResList.size()];
					String [] picNameString = new String[ResList.size()];
	    		
					for(int i = 0; i < ResList.size(); i++)
					{
						resNameString[i] = ResList.get(i).getResName();
						picNameString[i] = ResList.get(i).getResPicName();
					}
	    		
					setListAdapter(new IconAdapter(ResListActivity.this, resNameString, picNameString));
	    		
				}
				else{
	    	    	 		
					Log.i(tag, "this.reference.ResList == null");
				}

			}
			
    	
			if(!DEBUG){
    		
				mlocManager.removeUpdates(mlocListener);
			}


		}


		public void onProviderDisabled(String provider)
		{

			//Toast.makeText( getApplicationContext(), "Gps Disabled", Toast.LENGTH_SHORT ).show();

		}

		public void onProviderEnabled(String provider)
		{
			//Toast.makeText( getApplicationContext(), "Gps Enabled", Toast.LENGTH_SHORT).show();
		}

			
		public void onStatusChanged(String provider, int status, Bundle extras) 
		{
			// TODO Auto-generated method stub			
		}

	}
	
	/**
	 * Store variable for later use
	 * @param intent
	 */
	private void StoreVariables(Intent intent){
		
		intent.putExtra("MyRes", MyRes).putExtra("SearchFood", SearchFood).putExtra("ResZip", ResZip);
		
	}
	
	///// final Variables
	boolean DEBUG =  false;										//Variable to skip searching location by using GPS
	final static int SEARCH_INCREMENT = 1;
	final static int END_INDEX_INCREMENT = 1;
	final static String tag = ResListActivity.class.getName();

}